libxml2: XML parser and toolkit
===============================

Description
-----------

XML C parser and toolkit

License
-------

MIT

Upstream Contact
----------------

http://www.xmlsoft.org/index.html
